@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ar">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -101,7 +99,7 @@
     <message>
         <location filename="../qml/KeyboardLayout.qml" line="16"/>
         <source>Keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation> disposition du clavier</translation>
     </message>
     <message>
         <location filename="../qml/KeyboardLayout.qml" line="34"/>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>إلغاء</translation>
+            <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>هذه القصاصة متعارضة مع [%1]</translation>
+            <translation>هذه القصاصة متعارضة مع [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>إدارة طريقة المدخلة، قصاصات طريقة المدخلة، إعدادات متقدمة</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
