@@ -1,13 +1,11 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="cs">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
 <context>
     <name>AddonsPage</name>
     <message>
         <location filename="../qml/AddonsPage.qml" line="20"/>
         <source>Add-ons</source>
         <translation>Doplňky</translation>
-    </message>  
+    </message>
 </context>
 <context>
     <name>AdvancedSettingsModule</name>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+            <translation>Zrušit</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>Tento příkaz konfliktuje s [%1]</translation>
+            <translation>Tento příkaz konfliktuje s [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>Správa vstupních metod, příkazy pro vstupní metody, pokročilé nastavení</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
