@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>Abbrechen</translation>
+            <translation>Abbrechen</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -247,7 +245,7 @@
     <message>
         <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
         <source>Taiwan China</source>
-            <translation>Chinesisches Taiwan</translation>
+        <translation>Chinesisches Taiwan</translation>
     </message>
 </context>
 <context>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>Dieses Tastenkürzel konfliktiert mit [%1]</translation>
+            <translation>Dieses Tastenkürzel konfliktiert mit [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>Eingabemethodehündlung, Eingabe-Kürzel, Erweiterte Einstellungen</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
