@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hi_IN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -139,7 +137,7 @@
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
         <source>edit</source>
-    <translation>संपादित करें</translation>
+        <translation>संपादित करें</translation>
     </message>
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>रद्द करें</translation>
+            <translation>रद्द करें</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -305,4 +303,4 @@
         <translation>इनपुट मेथड प्रबंधन, इनपुट मेथड शॉर्टकट्स, उन्नत निर्देश</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
