@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>Odustani</translation>
+            <translation>Odustani</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -234,7 +232,7 @@
     <message>
         <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
         <source>Traditional Chinese (Chinese Hong Kong)</source>
-            <translation>Tradicionalna kineska (Kina Hong Kong)</translation>
+        <translation>Tradicionalna kineska (Kina Hong Kong)</translation>
     </message>
     <message>
         <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>Ova skraćenica se konfliktira s [%1]</translation>
+            <translation>Ova skraćenica se konfliktira s [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>Upravljanje metodama unosa, skraćenice metoda unosa, napredne postavke</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
