@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ka">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>გაუქმება</translation>
+            <translation>გაუქმება</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>ეს შემოკლება კონფლიქტს მონიშვნას [%1]</translation>
+            <translation>ეს შემოკლება კონფლიქტს მონიშვნას [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>შეყვანის მეთოდების მართვა, შეყვანის მეთოდების შემოკლებები, გამართვა</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
