@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="km_KH">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="km_KH">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -12,25 +10,21 @@
 <context>
     <name>AdvancedSettingsModule</name>
     <message>
-        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
         <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
         <source>Advanced Settings</source>
         <translation>ការកំណត់ត្រាមូលដ្ឋាន</translation>
     </message>
     <message>
-        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
         <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
         <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
         <translation>&quot;ការកំណត់ត្រាមូលដ្ឋាន&quot; មានប្រសិទ្ធភាពតែនៅពេលដែលកម្មវិធីបញ្ចូលមានការកំណត់ត្រាមូលដ្ឋានផ្ទាល់ ហើយការកំណត់ត្រាមូលដ្ឋានដែលកម្មវិធីបញ្ចូលមានផ្ទាល់ នឹងត្រូវបានគោះគង់</translation>
     </message>
     <message>
-        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
         <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
         <source>Global Config</source>
         <translation>ការកំណត់ត្រាភាគទូទៅ</translation>
     </message>
     <message>
-        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
         <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
         <source>Add-ons</source>
         <translation>កម្មវិធីបន្ថែម</translation>
@@ -40,16 +34,10 @@
         <source>Keyboard layout</source>
         <translation>ការកំណត់ត្រាការបញ្ចូល</translation>
     </message>
-    <message>
-        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
-        <source>Keyboard layout</source>
-        <translation>ការកំណត់ត្រាការបញ្ចូល</translation>
-    </message>
 </context>
 <context>
     <name>DetailConfigItem</name>
     <message>
-        <location filename="../qml/DetailConfigItem.qml" line="151"/>
         <location filename="../qml/DetailConfigItem.qml" line="151"/>
         <source>Please enter a new shortcut</source>
         <translation>សូមបញ្ចូលបន្ទាត់ថ្មីនៃការបញ្ជូល</translation>
@@ -58,25 +46,21 @@
 <context>
     <name>IMList</name>
     <message>
-        <location filename="../qml/IMList.qml" line="152"/>
         <location filename="../qml/IMList.qml" line="152"/>
         <source>Move Up</source>
         <translation>ផ្ទះឡើង</translation>
     </message>
     <message>
-        <location filename="../qml/IMList.qml" line="160"/>
         <location filename="../qml/IMList.qml" line="160"/>
         <source>Move Down</source>
         <translation>ផ្ទះចុះ</translation>
     </message>
     <message>
-        <location filename="../qml/IMList.qml" line="168"/>
         <location filename="../qml/IMList.qml" line="168"/>
         <source>Settings</source>
         <translation>ការកំណត់ត្រា</translation>
     </message>
     <message>
-        <location filename="../qml/IMList.qml" line="176"/>
         <location filename="../qml/IMList.qml" line="176"/>
         <source>Remove</source>
         <translation>បំបាក់</translation>
@@ -85,19 +69,16 @@
 <context>
     <name>InputMethodsChooser</name>
     <message>
-        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
         <location filename="../qml/InputMethodsChooser.qml" line="35"/>
         <source>Add input method</source>
         <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
     </message>
     <message>
-        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
         <location filename="../qml/InputMethodsChooser.qml" line="41"/>
         <source>Search</source>
         <translation>ស្វែងរក</translation>
     </message>
     <message>
-        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
         <location filename="../qml/InputMethodsChooser.qml" line="109"/>
         <source>Find more in App Store</source>
         <translation>ស្វែងរកបន្ថែមនៅ App Store</translation>
@@ -174,92 +155,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="30"/>
         <source>Add new keyboard layout</source>
-            <translation>បញ្ចូលការកំណត់ត្រាការបញ្ចូលថ្មី</translation>
-    </message>
-    <message>
-        <location filename="../qml/LayoutsChooser.qml" line="38"/>
-        <source>Search</source>
-        <translation>ស្វែងរក</translation>
-    </message>
-    <message>
-        <location filename="../qml/LayoutsChooser.qml" line="67"/>
-        <source>Current language keyboard layouts</source>
-        <translation>ការកំណត់ត្រាការបញ្ចូលនៃភាសាចង់របស់អ្នក</translation>
-    </message>
-    <message>
-        <location filename="../qml/LayoutsChooser.qml" line="90"/>
-        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
-        <source>Cancel</source>
-        <translation>បិទ</translation>
-    </message>
-    <message>
-        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
-        <source>Add</source>
-        <translation>បញ្ចូល</translation>
-    </message>
-</context>
-<context>
-    <name>KeyboardLayout</name>
-    <message>
-        <location filename="../qml/KeyboardLayout.qml" line="16"/>
-        <source>Keyboard layout</source>
-        <translation>ការកំណត់ត្រាការបញ្ចូល</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayout.qml" line="34"/>
-        <source>done</source>
-        <translation>បានជោគជ័យ</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayout.qml" line="34"/>
-        <source>edit</source>
-        <translation>កែប្រែ</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayout.qml" line="57"/>
-        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
-        <translation>បញ្ចូលកម្មវិធីបញ្ចូលដូចគ្នានៅ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; ដើម្បីបង្កើតស្ថានភាពការបញ្ចូលការបញ្ចូលនៅពេលបញ្ចូលឬផ្លាស់ប្ដូរ។</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayout.qml" line="142"/>
-        <source>Add new keyboard layout...</source>
-        <translation>បញ្ចូលការកំណត់ត្រាការបញ្ចូលថ្មី...</translation>
-    </message>
-</context>
-<context>
-    <name>KeyboardLayoutModule</name>
-    <message>
-        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
-        <source>Keyboard layout</source>
-        <translation>ការកំណត់ត្រាការបញ្ចូល</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
-        <source>done</source>
-        <translation>បានជោគជ័យ</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
-        <source>edit</source>
-        <translation>កែប្រែ</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
-        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
-        <translation>បញ្ចូលកម្មវិធីបញ្ចូលដូចគ្នានៅ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; ដើម្បីបង្កើតស្ថានភាពការបញ្ចូលការបញ្ចូលនៅពេលបញ្ចូលឬផ្លាស់ប្ដូរ។</translation>
-    </message>
-    <message>
-        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
-        <source>Add new keyboard layout...</source>
-        <translation>បញ្ចូលការកំណត់ត្រាការបញ្ចូលថ្មី...</translation>
-    </message>
-</context>
-<context>
-    <name>LayoutsChooser</name>
-    <message>
-        <location filename="../qml/LayoutsChooser.qml" line="30"/>
-        <source>Add new keyboard layout</source>
-            <translation>បញ្ចូលការកំណត់ត្រាការបញ្ចូលថ្មី</translation>
+        <translation>បញ្ចូលការកំណត់ត្រាការបញ្ចូលថ្មី</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="38"/>
@@ -274,10 +170,9 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>បិទ</translation>
+            <translation>បិទ</translation>
     </message>
     <message>
-        <location filename="../qml/LayoutsChooser.qml" line="97"/>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
         <source>Add</source>
         <translation>បញ្ចូល</translation>
@@ -291,7 +186,6 @@
         <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល</translation>
     </message>
     <message>
-        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
         <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
         <source>Add input method</source>
         <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
@@ -307,40 +201,27 @@
         <source>None</source>
         <translation>គ្មេាំង</translation>
     </message>
-    <message>
-        <location filename="../qml/ShortcutsModule.qml" line="119"/>
-        <location filename="../qml/ShortcutsModule.qml" line="12"/>
-        <location filename="../qml/ShortcutsModule.qml" line="14"/>
-        <location filename="../qml/ShortcutsModule.qml" line="151"/>
-        <location filename="../qml/ShortcutsModule.qml" line="152"/>
-        <source>None</source>
-        <translation>គ្មេាំង</translation>
-    </message>
     <message>
         <location filename="../qml/ShortcutsModule.qml" line="119"/>
         <source>Shortcuts</source>
         <translation>ការបញ្ជូលច្បាប់</translation>
     </message>
     <message>
-        <location filename="../qml/ShortcutsModule.qml" line="134"/>
         <location filename="../qml/ShortcutsModule.qml" line="134"/>
         <source>Restore Defaults</source>
         <translation>ស្វែងរកការបញ្ជូលច្បាប់ដើម</translation>
     </message>
     <message>
-        <location filename="../qml/ShortcutsModule.qml" line="200"/>
         <location filename="../qml/ShortcutsModule.qml" line="200"/>
         <source>Scroll between input methods</source>
         <translation>ផ្លាស់ប្ដូរកម្មវិធីបញ្ចូលតាមរយៈការផ្ទះផ្ទាល់</translation>
     </message>
     <message>
-        <location filename="../qml/ShortcutsModule.qml" line="230"/>
         <location filename="../qml/ShortcutsModule.qml" line="230"/>
         <source>Turn on or off input methods</source>
         <translation>បើកឬបិទកម្មវិធីបញ្ចូល</translation>
     </message>
     <message>
-        <location filename="../qml/ShortcutsModule.qml" line="273"/>
         <location filename="../qml/ShortcutsModule.qml" line="273"/>
         <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
         <translation>វាបើកឬបិទកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។ ប្រសិនបើគ្មេាំងកំណត់ត្រានៃកម្មវិធីបញ្ចូល ឬកម្មវិធីបញ្ចូលដំបូងមិនមានបច្បាប់ វានឹងផ្លាស់ប្ដូរពីកម្មវិធីបញ្ចូលដំបូងទៅកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។</translation>
@@ -372,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>ការបញ្ជូលច្បាប់នេះមានជំនួយខាងចុងខាងស្តាំ [%1]</translation>
+            <translation>ការបញ្ជូលច្បាប់នេះមានជំនួយខាងចុងខាងស្តាំ [%1]</translation>
     </message>
 </context>
 <context>
@@ -422,5 +303,4 @@
         <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល ការបញ្ជូលច្បាប់ និងការកំណត់ត្រាមូលដ្ឋាន</translation>
     </message>
 </context>
-</TS>
-
+</TS>
\ No newline at end of file
