@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="kn_IN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -34,7 +32,7 @@
     <message>
         <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
         <source>Keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -129,27 +127,27 @@
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
         <source>Keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
         <source>done</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
         <source>edit</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
         <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
         <source>Add new keyboard layout...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>ರದ್ದು</translation>
+            <translation>ರದ್ದು</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>ಈ ಶರ್ಕ್ಯಟ್ ಕಾನ್ಫ್ಲಿಕ್ಟ್ ಆಗಿದೆ [%1]</translation>
+            <translation>ಈ ಶರ್ಕ್ಯಟ್ ಕಾನ್ಫ್ಲಿಕ್ಟ್ ಆಗಿದೆ [%1]</translation>
     </message>
 </context>
 <context>
@@ -305,4 +303,4 @@
         <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ, ಇನ್ಪುಟ್ ಮೆಥಡ್ ಶರ್ಕ್ಯಟ್ಸ್, ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
