@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
 <context>
     <name>AddonsPage</name>
     <message>
@@ -19,7 +17,7 @@
     <message>
         <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
         <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
-        <translation>"Avancerade inställningar" gäller endast för indatametoden som använder systeminställningarna. Om indatametoden har sina egna inställningar ska dess egna inställningar gälla.</translation>
+        <translation>&quot;Avancerade inställningar&quot; gäller endast för indatametoden som använder systeminställningarna. Om indatametoden har sina egna inställningar ska dess egna inställningar gälla.</translation>
     </message>
     <message>
         <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
@@ -172,7 +170,7 @@
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="90"/>
         <source>Cancel</source>
-        <translation>Avbryt</translation>
+            <translation>Avbryt</translation>
     </message>
     <message>
         <location filename="../qml/LayoutsChooser.qml" line="97"/>
@@ -255,7 +253,7 @@
     <message>
         <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
         <source>This shortcut conflicts with [%1]</source>
-        <translation>Denna genväg står i konflikt med [%1]</translation>
+            <translation>Denna genväg står i konflikt med [%1]</translation>
     </message>
 </context>
 <context>
